@@ -18,12 +18,14 @@
     in future releases.
 """
 
+from inspect import getfile
 import logging
-import threading
+from os.path import abspath, split, join, isfile
 import sys
 
 import zoom
-from zoom.utils import OrderedSet
+from zoom.utils import OrderedSet, kind
+from zoom.tools import load
 
 
 class Component(object):
@@ -127,10 +129,14 @@ class Component(object):
         self.parts = {
             'html': [],
         }
+        self.load_assets()
         for arg in flatten(args):
             self += arg
         self += kwargs
 
+    def load_assets(self):
+        """load static assets"""
+
     def __iadd__(self, other):
         """add something to a component
 
@@ -185,7 +191,7 @@ class Component(object):
                 if key == 'html':
                     part.extend(value)
                 else:
-                    part |= value
+                    part |= filter(bool, value)
         return self
 
     def __add__(self, other):
@@ -217,6 +223,45 @@ class Component(object):
         zoom.system.parts += self
         return ''.join(map(str, self.parts['html']))
 
+    def format(self, *args, **kwargs):
+        """Return formatted object component"""
+
+        def js_fill(template, *args, **kwargs):
+            """fills a js template based on the parameters"""
+            def filler(name, *_, **__):
+                tpl = '{' + name + '}'
+                result = tpl.format(*args, **kwargs)
+                return result
+            result = zoom.fill.dollar_fill(template, filler)
+            return result
+
+        def css_fill(template, *args, **kwargs):
+            """fills a css template based on the parameters"""
+            def filler(name, *_, **__):
+                tpl = '{' + name + '}'
+                result = tpl.format(*args, **kwargs)
+                return result
+            result = zoom.fill.dollar_fill(template, filler)
+            return result
+
+        result = {}
+        for k, v in self.parts.items():
+            if k == 'html':
+                tpl = ''.join(map(str, v))
+                result[k] = tpl.format(*args, **kwargs)
+            elif k == 'js':
+                result[k] = ''.join(
+                    js_fill(segment, *args, **kwargs) for segment in v
+                )
+            elif k == 'css':
+                result[k] = ''.join(
+                    css_fill(segment, *args, **kwargs) for segment in v
+                )
+            else:
+                result[k] = ''.join(map(str, v))
+
+        return Component() + result
+
     def __str__(self):
         return self.render()
 
@@ -229,6 +274,31 @@ def render(*components):
 component = Component
 
 
+def load_assets(path, name):
+    """Return file based component assets for a named component"""
+    assets = {}
+    for ext in ['html', 'css', 'js']:
+        pathname = join(
+            path, name + '.' + ext
+        )
+        if isfile(pathname):
+            assets[ext] = load(pathname)
+    return assets
+
+
+class DynamicComponent(Component):
+    """A component that loads its parts from the file system"""
+
+    def load_assets(self):
+        path = split(abspath(getfile(self.__class__)))[0]
+        assets = load_assets(path, kind(self))
+        for k, v in assets.items():
+            if k == 'html':
+                self.parts['html'].insert(0, v)
+            else:
+                self.parts[k] = OrderedSet([v]) | self.parts.get(k, {})
+
+
 def compose(*args, **kwargs):
     """Compose a response - DEPRECATED"""
     zoom.system.parts += component(**kwargs)
